@@ -2,7 +2,6 @@ import sys, os
 import requests
 from . import helper
 import sqlite3 as sql
-from . import email_logo
 import smtplib, socket
 import csv, re, imghdr
 from pathlib import Path
@@ -10,7 +9,7 @@ from os.path import exists
 from os.path import basename
 from getpass import getuser
 from subprocess import call
-from . import mail_checker as mc
+from . import email_checker as mc
 from email.message import EmailMessage
 from tempfile import NamedTemporaryFile
 
@@ -64,13 +63,14 @@ def user_contacts(mode, emails=""):
 		c.execute("UPDATE contacts SET emails = ?", (emails,))
 		data.commit()
 
-def html_message(mode, html=""):
+def html_message(mode):
 	if mode == 'GET':
 		if not exists(HTML_FILE): return
 		with open(HTML_FILE, 'r') as f:
-			return f.read()
-	with open(HTML_FILE, 'w') as f:
-		f.write(html)
+			return f.read().strip()
+	call(['nano', HTML_FILE])
+	with open(HTML_FILE, 'r') as html:
+		if not html.read().strip(): os.remove(HTML_FILE)
 
 def message_attachments(mode, filename=""):
 	with sql.connect(DATABASE) as data:
@@ -99,9 +99,9 @@ def update_warning():
 	response = requests.get("https://pypi.org/pypi/mailshell/json")
 	current_version = response.json()['info']['version']
 	if helper.VERSION == current_version:
-		return ''
+		return ""
 	warning = f"\n\x1b[33mWARNING: new version available [{current_version}]\n"
-	warning += "run 'pip3 install -U mailshell' to update.\x1b[0m"
+	warning += "See 'pip3 install -U mailshell' to update.\x1b[0m\n"
 	return warning
 
 def validate_email(address):
@@ -111,13 +111,14 @@ def validate_email(address):
 		return True
 	return False
 
-def dispaly_logo():
-	print(email_logo.LOGO)
-
 def helpme():
-	call(['mshell', '--help'])
+	call(['msl', '--help'])
 
-def less(text=''):
+def show(text=''):
+	lines = os.get_terminal_size()[1]
+	if len(text.splitlines()) <= lines - 2:
+		print(text)
+		return
 	with NamedTemporaryFile(mode='w') as tmp:
 		tmp.write(text + "\nPress 'q' to END")
 		tmp.flush()
@@ -142,9 +143,7 @@ class User(object):
 class Mailshell():
 	def __init__(self):
 		self.commands = {
-			"logo": dispaly_logo,
 			"login": self.log_in,
-			"logout": self.log_out,
 			"cred": self.credentials,
 			"new": self.new_message,
 			"edit": self.edit_message,
@@ -159,7 +158,8 @@ class Mailshell():
 			"rm": self.remove_file,
 			"check": self.check_mail_box,
 			"sch": self.display_sc,
-			"help": helpme
+			"help": helpme,
+			"logout": self.log_out
 		}
 
 	def __error_login_first(self):
@@ -178,7 +178,7 @@ class Mailshell():
 
 	def __error_connection(self):
 		print("\nConnection error: please check your network!\n")
-	
+
 	def __has_message(self):
 		subj = user_message('GET')[0]
 		if subj: return True
@@ -205,8 +205,8 @@ class Mailshell():
 
 	def log_in(self):
 		print('\nLog in:')
-		address = input("Email address: ").strip()
-		password = input("App password: ").strip()
+		address = input("> Email address: ").strip()
+		password = input("> App password: ").strip()
 		try:
 			if validate_email(address):
 				try:
@@ -216,7 +216,7 @@ class Mailshell():
 					self.__error_app_password()
 					return
 			else:
-				print(f"ERROR: '{address}' does not exist.\n")
+				print(f"\nERROR: '{address}' does not exist.\n")
 				return
 			print(update_warning())
 		except Exception:
@@ -228,6 +228,7 @@ class Mailshell():
 
 	def log_out(self):
 		if not self.__has_user(): return
+		user_contacts('POST', '{}')
 		os.remove(CREDENTIALS_FILE)
 		print("\nYou have logged out.\n")
 
@@ -237,8 +238,8 @@ class Mailshell():
 		if not user:
 			self.__error_login_first()
 			return
-		print("\nEmail address:\t" + user.address)
-		print("Email app password:\t" + user.app_password, '\n')
+		print("\nEmail address:       " + user.address)
+		print("Email app password:  " + user.app_password, '\n')
 
 	def new_message(self):
 		if not self.__has_user(): return
@@ -260,18 +261,17 @@ class Mailshell():
 
 	def add_html(self):
 		if not self.__has_message(): return
-		new = self.__get_multiline_input(html_message('GET') or "", True)
-		if new: html_message('POST', html=new)
-		try: os.remove(HTML_FILE)
-		except: pass
+		html_message('POST')
 
 	def set_subject(self, allowed=False):
 		subj = user_message('GET')[0]
-		if not allowed and not subj:
-			self.__error_create_message()
-			return
+		if not allowed:
+			if not subj:
+				self.__error_create_message()
+				return
+			print("your current message subject is:", subj, "\nset a new one:")
 		while True:
-			subj = input("Subject: ").strip()
+			subj = input("> Subject: ").strip()
 			if subj:
 				user_message('POST', subject=subj)
 				break
@@ -280,11 +280,13 @@ class Mailshell():
 	def set_from(self, allowed=False):
 		user = User()
 		user.get_user()
-		subj = user_message('GET')[0]
-		if not allowed and not subj:
-			self.__error_create_message()
-			return
-		sdr = input("From: ").strip()
+		subj, sender, _ = user_message('GET')
+		if not allowed:
+			if not subj:
+				self.__error_create_message()
+				return
+			print("This message is from: ", sender, "\nset a new name:")
+		sdr = input("> From: ").strip()
 		if sdr: sdr += ' '
 		sdr += f"<{user.address}>"
 		user_message('POST', sender=sdr)
@@ -307,7 +309,7 @@ class Mailshell():
 			self.__error_file_not_found(file_path)
 			return
 		if os.path.isdir(file_path):
-			print(f"\n{file_path} is a folder not file.\n")
+			print(f"\n'{file_path}' is a folder not file.\n")
 			return
 		message_attachments('POST', os.path.abspath(file_path))
 					
@@ -318,17 +320,17 @@ class Mailshell():
 	def show_content(self):
 		if not self.__has_message(): return
 		line = '-' * len(MESSAGE_STR)
-		content = MESSAGE_STR + '\n'
+		content = '\n' + MESSAGE_STR + '\n'
 		subject, sender, text = user_message('GET')
-		content += f"Subject:\t{subject}\n" + f"From:\t{sender}\n"
+		content += f"Subject:  {subject}\nFrom:     {sender}\n"
 		if exists(HTML_FILE): text = html_message('GET')
-		content += text + '\n'
+		content += f"\n{text}\n"
 		attachments = message_attachments('GET')
 		if attachments:
-			content += line + "\n- includes:\n"
-			for att in attachments: content += f"\x1b[33m\t{basename(att)}\x1b[0m\n" 
-		print(content, '\n' + line)
-		print("type 'send' to send your message.\n")
+			content += line + "\n- includes:"
+			for att in attachments: content += f"\n\x1b[33m\t{basename(att)}\x1b[0m" 
+		show(content + '\n' + line)
+		print("Use 'msl send' to send your message.\n")
 
 	def check_mail_box(self):
 		user = User()
@@ -343,7 +345,7 @@ class Mailshell():
 			self.__error_connection()
 
 	def display_sc(self):
-		less(helper.IMAP_CRITERIAS)
+		show(helper.IMAP_CRITERIAS)
 
 	def message_to(self):
 		if not self.__has_user(): return
@@ -391,11 +393,11 @@ class Mailshell():
 				for user in contacts:
 					print(f"Sending to {user}..")
 					if not validate_email(user):
-						print(f"\x1b[31m    Error: {user} is not exist.\x1b[0m")
+						print(f"\t\x1b[31mError: {user} is not exist.\x1b[0m")
 						continue
 					message['To'] = user
 					smtp.send_message(message)
-					print("\x1b[32m    Email is successfully sent\x1b[0m")
+					print("\t\x1b[32mEmail is successfully sent\x1b[0m")
 			print(update_warning())
 		except socket.gaierror:
 			self.__error_connection()
@@ -405,16 +407,18 @@ class Mailshell():
 			connect_to_database()
 			if f: self.commands[cmd](f)
 			else: self.commands[cmd]()
-			return
-		print(f"'{cmd}' command not found.")
 		
 
 
 def run(arguments=None):
 	SHELL = Mailshell()
+	if arguments.version:
+		print("Mailshell", f"[ {helper.VERSION} ]")
+		return
 	if not arguments.command:
 		helpme()
 		return
+
 	try: command = [arguments.command, arguments.file]
 	except AttributeError: command = [arguments.command, None]
 	if command[0] == "rm" and arguments.all: command[1] = "*"
